* migstat08_spss.zip:   migstat08.sps .

* IBM SPSS Statistics 20, Release 20.0.0.1 .

set length none.
set width 132.
set header no.

* Arbeitsverzeichnis in '<...>' eintragen; z. B. c:\temp */ .
CD '<Arbeitsverzeichnis>'.

* ============================================================================.
*                                                                             .
* SPSS-PROGRAMM ZUR TYPISIERUNG DES MIGRATIONSSTATUS IM MIKROZENSUS 2008      .
*                                                                             .
* Programmautor/en:                                                           .
* SAS-Originalprogramm: Gunter Brueckner (Statistisches Bundesamt;            .
*             Referat F 204 Migration und integration, Wohnen)                .
* Anpassungen an Scientific Use File Mikrozensus 2008: Delia Jaeger,          .
*             Bernhard Schimpl-Neimanns (GESIS, GML)                          .
* Programmzweck:                                                              .
*   Dieses Programm dient der Replikation des Migrationsstatus, Variable MIG, .
*   und der Staatsangehoerigkeit zum Migrationsstatus (MIGS) im Scientific    .
*   Use File (SUF) des Mikrozensus 2008.                                      .
*   Die Programme basieren auf den SAS-Programmen zum Original-Mikrozensus    .
*   des Statistischen Bundesamtes und wurden an Recodierungen des SUF         .
*   angepasst.                                                                .
*   Bei der Replikation der Variablen Staatsangehoerigkeit zum Migrations-    .
*   status (MIGS) ist zu beachten, dass aus Gruenden des Datenschutzes        .
*   Angaben zur zweiten Staatsangehoerigkeit (EF370) nur rudimentaer          .
*   vorhanden sind. Des Weiteren sind die zur Konstruktion von MIGS           .
*   verwendeten Variablen                                                     .
*       EF369 1. Staatsangehoerigkeit                                         .
*   und EF374 Staatsangehoerigkeit: vor Einbuergerung/Zuzug als Spaetauss.    .
*   unterschiedlich codiert. Die Replikation ist deshalb nur eingeschraenkt   .
*   moeglich.                                                                 .
* Weiterfuehrende Programmbeschreibung:                                       .
*   Jaeger, Delia und Bernhard Schimpl-Neimanns: Typisierung des              .
*      Migrationshintergrundes in den Mikrozensus Scientific-Use-Files        .
*      2005-2009. GESIS-Technical Report Nr. 2012/08. Mannheim: GESIS.        .
*      URL: http://www.gesis.org/fileadmin/upload/forschung/publikationen/    .
*         gesis_reihen/gesis_methodenberichte/2012/TechnicalReport_2012-08.pdf.
* Download dieser Datei:                                                      .
*    http://www.gesis.org/missy/studie/klassifikationen/                      .
*    konzepte-und-definitionen/migrationshintergrund/migstat08_spss.zip       .
* Siehe auch Anhang 1: Personen mit Migrationshintergrund - Auf dem Weg zu    .
*   einer definitorischen Abgrenzung - S. 398-407 in:                         .
*   Statistisches Bundesamt, 2011: Bevoelkerung mit Migrationshintergrund.    .
*   Ergebnisse des Mikrozensus 2009. Fachserie 1 Reihe 2.2. Wiesbaden. URL:   .
*   https://www.destatis.de/DE/Publikationen/Thematisch/Bevoelkerung/         .
*   MigrationIntegration/Migrationshintergrund2010220097004.pdf?__blob=       .
*   publicationFile; letzter Zugriff: 24.07.2012                              .
* Programmstruktur:                                                           .
*   0. Datenvorbereitung                                                      .
*   1. Grundtypisierung des Migationshintergrundes                            .
*   2. Identifikation von 3-Generationen-Haushalten                           .
*   3. Endtypisierung der Grosseltern                                         .
*   4. Endtypisierung der Eltern                                              .
*   5. Endtypisierung Befragte                                                .
*   6. Umsetzung von Zeitreihenkompatibilitaet (entfaellt im MZ 2008)         .
*   7. Variablendefinition fuer SUF- und Fachserien-Ergebnisse                .
* Programmstatus:                                                             .
*   Getestet mit IBM SPSS Statistics 20, Release 20.0.0.1, und dem Scientific .
*   Use File Mikrozensus 2008, Version 2 vom 06. 04. 2011. Stand: Juli 2012   .
* ============================================================================.

* Variablenauswahl Scientific Use File Mikrozensus 2008, Version 2. 
*   Lokalen Dateinamen inkl. Verzeichnis in < > eintragen .
get file = '<mz2008.sav>' 
   /keep = EF1 EF3 EF4 EF5a EF5b EF8 EF9 EF12 EF30 EF31 EF37 EF44 EF46 
           EF47 EF49 EF50 EF51 EF52 EF53 EF54 EF55 EF366 EF367 EF368 
           EF369 EF370 EF371 EF372 EF373 EF374 EF663 EF732 EF952 EF5b 
           MIG MIGS
   /rename (mig=mig_O) (migs=migs_O) (EF374=EF374_O).

* Originalvariablen: MIG => MIG_O, MIGS => MIGS_O.
missing values all().


* ====================================================================.
* 0. DATENVORBEREITUNG .

* Neue Haushaltsnr. bilden, um extra Programme fuer Jahresbestand .
*      (EF5B=0) und Jahresueberhang (EF5b=1) zu vermeiden.
compute V4 = EF4 * 100 + EF5b * 10 + EF12.
var label V4 'HHNR EF4 * 100 + EF5b*10 + EF12'.
formats V4 (f4.0).

* Neue PERS.Nr.
compute V5 = EF5a.
var label V5 'PERS.NR im HH (ex EF5a)'.
formats V5 (f2.0).

sort cases by EF1  /* Bundesland */
              EF3  /* Auswahlbezirk */
              V4   /* fortlfd. HH-Nr. inkl. Jahresueberhang */
              V5.  /* neue Pers.nr. im HH */
execute.

* ---------------------------------------------------------------------.
* Harmonisierung Staatsangehoerigkeit: Anpassung von EF374 an EF369 und MIGS .
* EF374_O Originalfassung .
* 25 = Bulgarien(3); Rumaenien(25) .
*  4 = Daenemark(4); Finnland(8); Schweden(27).
* 21 = Belgien(1); Luxemburg(18); Niederlande(21).
* 31 = Estland(7); Lettland(15); Litauen(17); Malta(19); Slowenien(31); Zypern(37).
* 33 = Slowakei(30); Tschechische Republik(33).
* 55 = Uebrige Welt(55); Staatenlos(98) .
recode EF374_O (3=25) (8=4) (1=21)(7 15 17=31) (30=33) (98=55)(else=copy) into EF374.
var lab EF374 'Staatsangehoerigkeit: vor Einbuergerung/Zuzug als Spaetaussiedler - recodiert'.
formats EF374 (f2.0).
execute.

* Zu beachten: EF370 2. Staatsangehoerigkeit .
*       0 Auslaender mit nur einer Staatsangehoerigkeit .
*       1 Nur deutsche Staatsangehoerigkeit / Deutsche und weitere Staatsangehoerigkeit .
* Die einzelnen Staatsangehoerigkeiten sind nicht ausgewiesen.
* Um Fehlinterpretationen durch die Zuweisung "SA2=ef370" zu vermeiden, wird diese unten deaktiviert. 
* ---------------------------------------------------------------------.


* ====================================================================.
* 1: Grundtypisierung des Migrationshintergrundes                     .
*       Es werden zunaechst nur die Angaben der Person selbst zur     .
*       Typisierung verwendet. Die erste Typisierung erfolgt nach     .
*       Angaben zur Staatsangehoerigkeit (deutsch / nicht-deutsch)    .
*       und Geburtsland (Ausland / Inland).                           .
*       Zur Unterscheidung der Gruppe eingebuergerter Zuwanderer      .
*       (MIG=31) nach einem evtl. Status als Spaetaussiedler wird     .
*       abschliessend geprueft ob der Ehegatte, der Vater oder die    .
*       Mutter im Haushalt einen Spaetaussiedlerstatus besitzt.       .
*       Trifft dies zu, erfolgt eine Rekodierung (Plausibilisierung)  .
*       von MIG=31 'zugewanderter eingebuergerter Auslaender'         .
*       zu  MIG=22 'Ehegatte oder Kind eines (Spaet-)Aussiedlers      .
*                   (mit/ohne Einbuerg)'.                             .

compute Gebj=EF47.
var label Gebj 'Geburtsjahr (EF47)'.
formats Gebj (f4.0).

compute BRDBorn=EF366.
var label BRDBorn 'Geburtsland: BRD (EF366)'.
formats BRDBorn (f1.0).
val label BRDBorn 1 'Ja, hier geboren' 
                  8 'Nein, zugezogen' 
                  9 'ohne Angabe'.

recode BRDBorn (1=0) (8=1) (9=9) (else=9) into Zuzug.
var label Zuzug 'Zuzug ex BRDBorn, EF366'.
formats Zuzug (f1.0).
value label Zuzug 0 'kein Zuzug' 
                  1 'foreign born' 
                  2 'Zuzug nach 6+ Mo im Ausland:= in D geboren' 
                  9 'k.A.'.

compute JZuzug=EF367.
if (EF367=1949) JZuzug=1949. /* Zuzug vor 1950 */
if (EF367=9999) JZuzug=9.    /* o.A. zum Zuzugsjahr */
if (EF367=0)    JZuzug=0.    /* kein Zuzugsjahr sinnvoll */
var lab JZuzug 'Zuzugsjahr'.
formats JZuzug (f4.0).
value label JZuzug 1949 'Zuzug vor 1950' 
                      9 'o.A. zum Zuzugsjahr'  
                      0 'kein Zuzugsjahr sinnvoll'.

if (BRDBorn=1 & JZuzug>9) Zuzug=2.
if (BRDBorn=8 & JZuzug<10) JZuzug=9.

* SA*: Staatsangehoerigkeit .
* nur deutsche SA .
do if (EF368=1).
   compute Ausl=0.
   compute SADopp=0.
   compute SA1=0.
   recode EF30 (else=sysmis) into SA2.
* deutsche und auslaendische SA .
else if (EF368=2). 
   compute Ausl=0.
   compute SADopp=1.
   compute SA1=0.
   compute SA2=EF369.
* nur auslaendische SAs .
else.
   compute Ausl=1.
   compute SA1=EF369.
   if (EF370=0) SADopp=0.
   if (EF370<>0) SADopp=1. /* DEAKTIVIERT: if (EF370<>0) SA2=EF370 */
end if.

var lab SA1 'Aktuelle (erste) Staatsangehoerigkeit (EF368-EF370)'.
var lab SA2 'Aktuelle (zweite) Staatsangehoerigkeit (EF368-EF370)'.
var lab SADopp 'Doppelte Staatsangehoerigkeit (EF368-EF370)'.
var lab Ausl 'Auslaendische Staatsangehoerigkeit'.
val lab Ausl SADopp 0 'nein' 1 'ja'.
formats Ausl SADopp SA1 (f1.0) SA2 (f2.0).
execute.

* Spaetaussiedler mit Einbuergerung .
do if (EF372=2).
   compute SpAuss=1.
   compute Eingeb=1.
   recode EF373 (0=9) (else=copy) into JEinb.
   recode EF374 (0=sysmis) (else=copy) into SA3.
   recode EF369 (0=sysmis) (else=copy) into SA2.
* Spaetaussiedler ohne Einbuergerung .
else if (EF372=4).
   compute SpAuss=1.
   compute Eingeb=0.
   recode EF373 (else=sysmis) into JEinb. 
   recode EF374 (0=sysmis) (else=copy) into SA3.
   recode EF369 (0=sysmis) into SA2.
* sonstige Einbuergerung .
else if (EF372=3).
   compute SpAuss=0.
   compute Eingeb=1.
   recode EF373 (0=9) (else=copy) into JEinb.
   recode EF374 (0=sysmis) (else=copy) into SA3.
   recode EF369 (0=sysmis) (else=copy) into SA2.
else.
  compute SpAuss=0.
  compute Eingeb=0.
  recode  Eingeb (else=sysmis) into JEinb.
  compute SA3=0.
  recode EF369 (0=sysmis) (else=copy) into SA2.
end if.

var lab SpAuss 'Spaetaussiedler'.
var lab Eingeb 'Eingebuergert'.
var lab JEinb 'Einbuergerungsjahr'.
var lab SA3 'Staatsangeh. vor Einbuergerung/Zuzug als Spaetaussiedler'.
formats SpAuss Eingeb (f1.0) JEinb (f4.0) SA3 (f2.0).
val lab SpAuss Eingeb 0 'nein' 1 'ja'.
execute.

* -------------------------------------------------------------------.
* Ueberblick zu nachfolgenden Zuweisungen                            .
* MIG: Migrationstypus                                               .
*      1. Stelle: Migrationstyp:                                     .
*                 1=vertrieben                                       .
*                 2=als Deutsche/r bzw. Spaetaussiedler zugewandert  .
*                 3=eingebuergert                                    .
*                 4=Auslaender/in                                    .
*      2. Stelle: Generation:                                        .
*                 1=im Ausland geboren                               .
*                 2=in Deutschland geboren                           .
* Vorlaeufige Codes MIG                                              .
* 11=Vertriebene vor 1950                                            .
* 21=Deutsche Zuwanderer oder (Spaet-)Aussiedler (ohne Einbuergerung).
* 22=Ehegatte o. Kind eines (Spaet-)Aussiedlers (mit/ohne Einbuerg.) .
* 25=(Spaet-)Aussiedler (mit Einbuergerung)                          .
* 29=(Spaet-)Aussiedler (mit/ohne Einbuergerung) o.A. zum Zuzugsjahr .
* 31=zugewanderter eingebuergerter Auslaender                        .
* 32=nicht zugewanderter eingebuergerter Auslaender                  .
* 41=zugewanderter Auslaender                                        .
* 42=nicht zugewanderter Auslaender                                  .
* 77=uneindeutig ob deutsch, vertrieben oder Spaetaussiedler         .
* 99=fehlende/unvollstaendige Angaben                                .
* ----------------------------------                                 .
* SA_erw: Erweiterte aktuelle Staatsangehoerigkeit                   .
*         [Basis fuer MIGS Staatsangehoerigkeit: Migrationsstatus]   .
*         gewonnen aus                                               .
*           SA1 Aktuelle (erste) Staatsangehoerigkeit (EF368-EF370)  .
*           SA2 Aktuelle (zweite) Staatsangehoerigkeit (EF368-EF370) .
*           SA3 Staatsangeh. vor Einbuerg./Zuzug als Spaetaussiedler .
*         nach folgenden Regeln:                                     .
* SA_erw = 0   = deutsch (bei MIG=0, 11)                             .
*        = SA1 (bei Mig=41,42)                                       .
*        = SA3 (bei Mig=21,25,29,31,32 und SA3<>.)                   . 
*        = SA2 (bei MIG=21,25,29,31,32 und SA3=. und SA2<>.)         .
*        = 99  (bei MIG=21,25,29,31,32 und SA2=. und SA3=. oder      .
*               bei MIG=77,99)                                       .
*          [Sysmis sind oben bezeichnet mit: "." ]                   .
* -------------------------------------------------------------------.

* A) im Ausland geboren.
* A1) als Auslaender zugewandert. 
do if (BRDBorn=8 & Ausl=1).
       compute MIG=41.
       compute SA=SA1.
       compute SA_erw=SA1.
* A2) Spaetaussiedler/in .
*     SA_erw: SA vor Einbuergerung .
*             wenn fehlt, 2. SA (Doppelstaatler) .
*             ansonsten 'missing' .
else if (BRDBorn=8 & SpAuss=1 & Eingeb=1).
       compute MIG=25.
       compute SA=SA1.
       compute SA_erw=SA3.
       if (sysmis(SA_erw)) SA_erw=SA2.
       if (sysmis(SA_erw)) SA_erw=99.

* Spaetaussiedler ohne Einbuergerung  .
else if (BRDBorn=8 & SpAuss=1 & Eingeb=0).
       compute MIG=21.
       compute SA=SA1.
       compute SA_erw=SA3.
       if (sysmis(SA_erw)) SA_erw=SA2.
       if (sysmis(SA_erw)) SA_erw=99.

* kein Spaetaussiedler ... .
* A3) Eingebuergerte/r .
else if (BRDBorn=8 & SpAuss=0 & Eingeb=1).
       compute MIG=31.
       compute SA=SA1.
       compute SA_erw=SA3.
       if (sysmis(SA_erw)) SA_erw=SA2.
       if (sysmis(SA_erw)) SA_erw=99.
* ... Deutsche/r durch Geburt.
* A4) Vertriebener vor 1950 .
else if (BRDBorn=8 & SpAuss=0 & Eingeb=0 & JZuzug=1949).
       compute MIG=11.
       compute SA=SA1.
       compute SA_erw=SA1.
* A5) Aussiedler-aequivalent .
else if (BRDBorn=8 & SpAuss=0 & Eingeb=0 & JZuzug>1949).
       compute MIG=21.
       compute SA=SA1.
       compute SA_erw=SA3.
       if (sysmis(SA_erw)) SA_erw=SA2.
       if (sysmis(SA_erw)) SA_erw=99.
* ... Zuzugsjahr missing: Zuzug ohne Angabe zum Jahr d.h. kann .
*                         Vertriebener oder Spaetaussiedler sein.
* Annahme 1: wenn nach 1949 geboren, dann als Spaetaussiedler 
*            zugewandert.
else if (BRDBorn=8 & SpAuss=0 & Eingeb=0 & JZuzug=9 & Gebj>1949).
       compute MIG=21.
       compute SA=SA1.
       compute SA_erw=SA3.
       if (sysmis(SA_erw)) SA_erw=SA2.
       if (sysmis(SA_erw)) SA_erw=99.
* Annahme 2: Wenn vor 1949 geboren und keine auslaendaendische SA, .
*            dann Vertriebener .
else if (BRDBorn=8 & SpAuss=0 & Eingeb=0 & Gebj<=1949 & SADopp=0 & SA1=0).
       compute MIG=11.
       compute SA=SA1.
       compute SA_erw=SA1.
* Annahme 3: sonst Zuzug als Spaetaussiedler ohne Datumsangabe: 29 .
else if (BRDBorn=8 & SpAuss=0 & Eingeb=0 & JZuzug=9 & Gebj<=1949 & 
         SADopp=1 & SA1=0).
       compute MIG=29.
       compute SA=SA1.
       compute SA_erw=SA3.
       if (sysmis(SA_erw)) SA_erw=SA2.
       if (sysmis(SA_erw)) SA_erw=99.
* B) im Inland geboren: .
* B1) als Auslaender in D geboren .
else if (BRDBorn=1 & Ausl=1).
       compute MIG=42.
       compute SA=SA1.
       compute SA_erw=SA1.
* B2) Spaetaussiedler/in, Fehler! .
else if (BRDBorn=1 & SpAuss=1).
       compute MIG=77.
       compute SA=SA1. 
       compute SA_erw=SA3.
       if (sysmis(SA_erw)) SA_erw=SA2.
       if (sysmis(SA_erw)) SA_erw=99.
* B3) Eingebuergerte/r .
else if (BRDBorn=1 & Eingeb=1).
       /* Unterschied im SUF if (EF5b=0) MIG=32 Fassung fuer Jahresbestand */
       /*                    if (EF5b=1) MIG=31 Fassung fuer Jahresueberhang aufgehoben */
       compute MIG=32.
       compute SA=SA1. 
       compute SA_erw=SA3.
       if (sysmis(SA_erw)) SA_erw=SA2.
       if (sysmis(SA_erw)) SA_erw=99.
* B4) in Deutschland geborener Deutscher .
else if (BRDBorn=1 & Ausl=0 & SpAuss=0 & Eingeb=0).
       compute MIG=77.
       compute SA=SA1. 
       compute SA_erw=SA2.
       if (sysmis(SA_erw)) SA_erw=SA1.
*   BRDBorn=9: keine Auskunft; kommt wohl nicht vor .
else if (BRDBorn=9).
       compute Mig=99.
       compute SA=SA1.
       compute SA_erw=SA3.
       if (sysmis(SA_erw)) SA_erw=SA1.
end if.

formats BRDBorn Zuzug Ausl SADopp SpAuss Eingeb (f1.0).
formats SA SA1 SA2 SA3 SA_erw  MIG (f2.0).
formats Gebj  JZuzug JEinb (f4.0).
var lab SA 'Aktuelle Staatsangehoerigkeit'. 
var lab SA_erw 'Erweiterte aktuelle Staatsangehoerigkeit'.
var lab MIG 'Migrationsstatus'.
recode MIG (sysmis=0).
val label MIG 
    0 'SYSMIS'
   11 'Vertriebene vor 1950'
   21 'Deutsche Zuwanderer oder (Spaet-)Aussiedler (ohne Einbuergerung)'
   22 'Ehegatte oder Kind eines (Spaet-)Aussiedlers (mit/ohne Einbuergerung)'
   25 '(Spaet-)Aussiedler (mit Einbuergerung)'
   29 '(Spaet-)Aussiedler (mit/ohne Einbuergerung) o.A. zum Zuzugsjahr'
   31 'zugewanderte/r eingebuergerte/r Auslaender/in'
   32 'nicht zugewanderte/r eingebuergerte/r Auslaender/in'
   41 'zugewanderte/r Auslaender/in'
   42 'nicht zugewanderte/r Auslaender/in'
   77 'uneindeutig ob deutsch, vertrieben oder Spaetaussiedler'
   99 'fehlende/unvollstaendige Angaben'.
execute.


* Mig-Status vor Plausibilisierungen.
* fre mig.

* -------------------------------------------------------------------.
* Wenn Zuwanderer angibt, eingebuergert zu sein (Mig=31), dann .
* pruefen, ob ggf. Spaetaussiedlerstatus vorliegt .
* a) Ehegatte ist Spaetaussiedler (MIG[Ehegatte]=21-29) .
* b) Vater ist Spaetaussiedler (MIG[Vater]=21-29) .
* c) Mutter ist Spaetaussiedler (MIG[Mutter]=21-29) .
* Nachfolgende Pruefungen der Gruppe der Zuwanderer mit Angaben zu .
* einer Einbuergerung, ob ggf. ein Spaetaussiedlerstatus vorliegt, . 
* gehen von dieser Definition valider Spaetaussiedler .
* (ex: 02Vorlauf.sas) aus:  .
*   EF366 = 8 &               (Geburtsland nicht BRD)  .
*   & (EF372 = 2 | EF372 = 4) (Besitz der deutschen Staatsangeh. 
*                              als (Spaet-)Aussiedler mit (2) oder .
*                              ohne (4) Einbuergerung) . 
*   & JZuzug>1949             (Zuzugsjahr nach 1949).
* -------------------------------------------------------------------.

* Der in den einzelnen Programmschritten gebildete Migrationsstatus .
*    (MIG) wird zur Kontrolle der jeweiligen Rekodierungen umbenannt.
*    Am Ende erhaelt die Typisierung wieder den Variablennamen MIG.  
rename variables (MIG = MIG1).
var label MIG1 'Migrationsstatus vor Plausibilisierung a) Ehegatte'.

* -------------------------------------------------------------------.
* A) PLAUSIBILISIERUNG - EHEGATTE .
compute VORL = (EF366=8 & (EF372=2 | EF372=4) & JZuzug>1949). 
var label VORL 'Valide Spaetaussiedler - PERSON'.
formats VORL (f1.0).

temporary.
select if (EF50=1)  /* Ehegatte im Haushalt */ .
save /outfile='temp_E.sav'
     /keep  = EF1 EF3 V4 V5 mig1 VORL JZuzug EF366 EF372 
     /rename (V5   JZuzug   EF366   EF372   mig1   VORL = 
              EF5_E JZuzug_E EF366_E EF372_E mig1_E VORL_E).
execute.

if (EF50=1) EF5_E = EF51.
var label EF5_E 'Nr. des Ehepartners im Haushalt (EF51)'.
formats EF5_E (f2.0).

* Sortierung fuer Zusammenspielen mit Angaben der Ehegatten. 
sort cases by EF1 EF3 V4 EF5_E.

* Angaben der Ehegatten zusammenspielen. 
match files file=*
           /table='temp_E.sav'
           /by EF1 EF3 V4 EF5_E.
execute.

* Sortierung des Ausgangsfiles .
sort cases by  EF1 EF3 V4 V5 .

* Pruefung und Rekodierung. 
compute MIG1a=MIG1.
if (MIG1=31       /* Wenn Zuwanderer angibt, eingebuergert zu sein */
    & JZuzug>10   /* und valides Zuzugsjahr */
    & EF50=1      /* Ehegatte im Haushalt (ergaenzt) */
    & (abs(JZuzug-JZuzug_E)<3)  /* Diff Zuzugsjahre +- 3 Jahre  */
    & VORL_E=1)   /* Ehegatte ist valider Spaetaussiedler */
    MIG1a=22.
formats MIG1a (f2.0).
var label MIG1a 'Migrationsstatus nach Plausib a) Ehegatte'.

* ----------------------------------------------------------------------------.
* B) PLAUSIBILISIERUNG - VATER .
compute vnr = EF55 * (EF54=1).
formats vnr (f2.0).
var label vnr 'Personennr. des Vaters (EF55)'.

* ==> Sortierung ... vnr.
sort cases by  EF1 EF3 V4 vnr.

temporary.
select if (vnr>0).
compute V5=vnr.
aggregate outfile='temp_V1.sav'
     /break EF1 EF3 V4 V5
     /V_Kids 'Kinder des Vaters' = n.
execute.

sort cases by  EF1 EF3 V4 V5.
* Angaben des Vaters zuspielen. 
match files file=*
           /table='temp_V1.sav'
           /by EF1 EF3 V4 V5.
execute.

recode V_Kids (1 thru hi=1) into VATER.
var label VATER 'Vater lediger Kinder im HH'.
formats VATER (f1.0).

temporary.
select if (VATER=1).
save /outfile='temp_V2.sav'
     /keep  = EF1 EF3 V4 V5 mig1a VORL JZuzug EF366 EF372 
     /rename (V5  JZuzug   EF366   EF372   mig1a   VORL = 
              vnr JZuzug_V EF366_V EF372_V mig1a_V VORL_V).
execute.

* Sortierung fuer Zusammenspielen VATER. 
sort cases by EF1 EF3 V4 vnr.

* Angaben des Vaters zuspielen. 
match files file=*
           /table='temp_V2.sav'
           /by EF1 EF3 V4 vnr.
execute.

* Sortierung des Ausgangsfiles wieder herstellen: .
sort cases by  EF1 EF3 V4 V5 .

* Pruefung und Rekodierung. 
compute MIG1b=MIG1a.
execute.
if (MIG1a=31        /* Wenn Zuwanderer angibt, eingebuergert zu sein */
    & JZuzug>10     /* und valides Zuzugsjahr */
    & EF54=1        /* Vater im Haushalt (ergaenzt) */
    & (abs(JZuzug-JZuzug_V)<3)  /* Diff Zuzugsjahre +- 3 Jahre */
    & VORL_V=1)     /* Vater ist valider Spaetaussiedler */
    MIG1b=22.
formats MIG1b (f2.0).
var label MIG1b 'Migrationsstatus nach Plausib a) Eheg. + b) Vater'.
execute.

* -------------------------------------------------------------------.
* C) PLAUSIBILISIERUNG - MUTTER .
compute mnr = EF53 * (EF52=1).
formats mnr (f2.0).
var label mnr 'Personennr. der Mutter (EF53)'.

* ==> Sortierung ... mnr.
sort cases by  EF1 EF3 V4 mnr.

temporary.
select if (mnr>0).
compute V5=mnr.
aggregate outfile='temp_M1.sav'
     /break EF1 EF3 V4 V5
     /M_Kids 'Kinder der Mutter' = n.
execute.

sort cases by  EF1 EF3 V4 V5.
* Angaben der Mutter zuspielen. 
match files file=*
           /table='temp_M1.sav'
           /by EF1 EF3 V4 V5.
execute.

recode M_Kids (1 thru hi=1) into MUTTER.
var label MUTTER 'Mutter lediger Kinder im HH'.
formats MUTTER (f1.0).

temporary.
select if (MUTTER=1).
save /outfile='temp_M2.sav'
     /keep  = EF1 EF3 V4 V5 mig1b   VORL    JZuzug  EF366 EF372 
     /rename (V5  JZuzug    EF366   EF372   mig1b   VORL = 
              mnr JZuzug_M  EF366_M EF372_M mig1b_M VORL_M).
execute.

* Sortierung fuer Zusammenspielen MUTTER. 
sort cases by EF1 EF3 V4 mnr.

* Angaben der Mutter zuspielen. 
match files file=*
           /table='temp_M2.sav'
           /by EF1 EF3 V4 mnr.
execute.

* Sortierung des Ausgangsfiles wieder herstellen: .
sort cases by  EF1 EF3 V4 V5 .

* Pruefung und Rekodierung. 
compute MIG1c=MIG1b.
execute.
if (MIG1b=31        /* Wenn Zuwanderer angibt, eingebuergert zu sein */
    & JZuzug>10     /* und valides Zuzugsjahr */
    & EF52=1        /* Mutter im Haushalt (ergaenzt) */
    & (abs(JZuzug-JZuzug_M)<3)  /* Diff Zuzugsjahre +- 3 Jahre */
    & VORL_M=1)    /* Mutter ist valider Spaetaussiedler */
    MIG1c=22.
formats MIG1c (f2.0).
var label MIG1c 'Migrationsstatus nach Plausib a), b) + c) Mutter'.
execute.

compute MIG2 = MIG1c.
formats MIG2 (f2.0).
var label MIG2 'Migrationsstatus nach Plausibilisierungen (MIG=31, a-c)'.
val label MIG2 
    0 'SYSMIS'
   11 'Vertriebene vor 1950'
   21 'Deutsche Zuwanderer oder (Spaet-)Aussiedler (ohne Einbuergerung)'
   22 'Ehegatte oder Kind eines (Spaet-)Aussiedlers (mit/ohne Einbuergerung)'
   25 '(Spaet-)Aussiedler (mit Einbuergerung)'
   29 '(Spaet-)Aussiedler (mit/ohne Einbuergerung) o.A. zum Zuzugsjahr'
   31 'zugewanderte/r eingebuergerte/r Auslaender/in'
   32 'nicht zugewanderte/r eingebuergerte/r Auslaender/in'
   41 'zugewanderte/r Auslaender/in'
   42 'nicht zugewanderte/r Auslaender/in'
   77 'uneindeutig ob deutsch, vertrieben oder Spaetaussiedler'
   99 'fehlende/unvollstaendige Angaben'.
   
*   Ausgangssortierung .
sort cases by  EF1 EF3 V4 V5.

* Mig-Status nach Plausibilisierungen.
* fre mig2.

* ====================================================================.
* 2. Identifikation von 3-Generationen-Haushalten                     .
*    Fuer die nachfolgende Typisierung des Migrationshintergrundes    .
*    von Eltern unter Verwendung von Angaben der Grosseltern werden   .
*    in diesem Schritt 3-Generationen-Haushalte identifiziert und     .
*    Identifikatoren fuer Grossmuetter- und -vaeter gebildet.         .

* Eltern (Mutter oder Vater) mit Angaben zur (Gross-)Mutter: .
*   Personennummer der Grossmutter .
compute gmnr = ( (MUTTER=1 | VATER=1) & EF52=1) * EF53.
* Eltern (Mutter oder Vater) mit Angaben zum (Gross-)Vater: 
*   Personennummer des Grossvaters .
compute gvnr = ( (MUTTER=1 | VATER=1) & EF54=1) * EF55. 

temporary.
* Eltern - Pers.Nr. der Grosseltern .
select if (MUTTER=1 | VATER=1).
aggregate outfile = 'temp_GE.sav'
         /presorted
         /break EF1 EF3 V4 
         /min_gmnr = min(gmnr)
         /max_gmnr = max(gmnr)
         /min_gvnr = min(gvnr)
         /max_gvnr = max(gvnr).
execute.

* Personennr. der Grosseltern zuspielen. 
match files file=*
           /table='temp_GE.sav'
           /by EF1 EF3 V4 .
formats gmnr gvnr min_gmnr max_gmnr min_gvnr max_gvnr (f2.0).
execute.

* Ausgangssortierung fuer Tests.
sort cases by  EF1 EF3 V4 V5 .

* Kontrolle: mehr als 1 Grossmutter(nummer) im HH? .
*            Voraussetzung fuer spaetere Verwendung von .
*            'max' gmnr gvnr ist, dass dies nicht zutrifft.
* temporary.
* select if (max_gmnr<>min_gmnr & min_gmnr>0).
* crosstabs max_gmnr by min_gmnr.

* Kontrolle: mehr als 1 Grossvater(nummer) im HH? .
* temporary.
* select if (max_gvnr<>min_gvnr & min_gvnr>0).
* crosstabs max_gvnr by min_gvnr.
* temporary.
* select if (ef3=8006 & ef4=2).
* list variables ef5b ef12 ef5a ef55 gvnr ef44 ef46 vater gvater v_kids.
* Korrektur unten (unerheblich, da mig=77).

* Grossvater-/mutter .
compute GMutter = (max_gmnr=V5 & max_gmnr>0).
compute GVater  = (max_gvnr=V5 & max_gvnr>0).
* Korrektur .
if (ef3=8006 & ef4=2) gvater = $sysmis.
if (ef3=8006 & ef4=2) max_gvnr = $sysmis.
if (ef3=8006 & ef4=2) min_gvnr = $sysmis.
if (ef3=8006 & ef4=2) gvnr = $sysmis.
if (ef3=8006 & ef4=2 & ef5a=2) vater  = $sysmis.
if (ef3=8006 & ef4=2 & ef5a=2) v_kids = $sysmis.
if (ef3=8006 & ef4=2 & ef5a=2) v_kids = $sysmis.

var label GMutter 'Grossmutter mit Kindern, Enkeln im HH'.
var label GVater  'Grossvater mit Kindern, Enkeln im HH'.
* val label GMutter GVater 1 'ja'.
formats GMutter GVater (f1.0).
execute.


* 3. Endtypisierung der Grosseltern .
*    Im MZ 2008 nicht relevant, da keine Angaben zu den nicht im HH lebenden .
*    Eltern vorhanden, deshalb kann die Grundtypisierung verwendet werden.



* ====================================================================.
* 4. Endtypisierung der Eltern                                        .
*      Fuer jede Kombination von eigenem, vaeterlichen und            .
*      muetterlichen vorlaeufigen Migrationsstatus wird der           .
*      resultierende endgueltige Migrationsstatus zugewiesen. Diese   .
*      Konversions-Prozedur wird nur fuer im Inland Geborene angewandt.
*      Abschliessend wird die Variable erweiterte Staatsangehoerigkeit.
*      (SA_erw) ggf. durch Informationen zum Vater bzw. zur Mutter    .
*      ergaenzt.                                                      .

* Ausgangssortierung.
sort cases by  EF1 EF3 V4 V5.

* Angaben zum Migrationsstatus des Grossvaters speichern.
temporary.
select if (GVater=1).
save outfile = 'temp_GV.sav'
         /keep EF3 V4 V5     MIG2   SA1    SA2    SA3   SA    SA_erw  
         /rename (V5  MIG2   SA1    SA2    SA3    SA    SA_erw = 
                  gvnr MIG_GV SA1_GV SA2_GV SA3_GV SA_GV SAerw_GV).
execute.

* Sortierung fuer Zusammenspielen Eltern- mit Grossvater-Angaben.
sort cases by EF1 EF3 V4 gvnr.

* Angaben der (Gross-) Vaeter zuspielen. 
match files file=*
           /table='temp_GV.sav'
           /by EF3 V4 gvnr.
execute.

* Ausgangssortierung.
sort cases by  EF1 EF3 V4 V5.

* Angaben zum Status des Grossvaters nur falls der Grossvater .
*   der Vater ist, sonst SYSMIS.
do if (gvnr<>EF55).
 recode MIG_GV SA1_GV SA2_GV SA3_GV SA_GV SAerw_GV (else=sysmis).
end if.
formats MIG_GV SA1_GV SA2_GV SA3_GV SA_GV SAerw_GV (f2.0).
execute.

* Angaben zum Migrationsstatus der Grossmutter speichern.
temporary.
select if (GMutter=1).
save outfile = 'temp_GM.sav'
         /keep EF3 V4   V5 MIG2 SA1 SA2 SA3 SA SA_erw  
         /rename (V5   MIG2   SA1    SA2    SA3    SA    SA_erw = 
                  gmnr MIG_GM SA1_GM SA2_GM SA3_GM SA_GM SAerw_GM).
execute.

* Sortierung fuer Zusammenspielen Eltern- mit Grossmutter-Angaben.
sort cases by EF1 EF3 V4 gmnr.

* Angaben der (Gross-) Muetter zuspielen. 
match files file=*
           /table='temp_GM.sav'
           /by EF3 V4 gmnr.
execute.

* Ausgangssortierung.
sort cases by  EF1 EF3 V4 V5.

* Angaben zum Status der Grossmutter nur falls die Grossmutter .
*   die Mutter ist, sonst SYSMIS.
do if (gmnr<>EF53).
   recode MIG_GM SA1_GM SA2_GM SA3_GM SA_GM SAerw_GM (else=sysmis).
end if.
formats MIG_GM SA1_GM SA2_GM SA3_GM SA_GM SAerw_GM (f2.0).
execute.

* -------------------------------------------------------------------------.
* Ab hier die eigentliche Endtypisierung des Migrationsstatus der .
*    Eltern mittels Konversions-Prozedur, bei der nur im Inland   .
*    Geborene beruecksichtigt werden                               .
if not any (MIG2, 11, 21, 22, 23, 25, 29, 31, 41) KonvProc=1.
var lab KonvProc 'Konversionsprozedur: gueltige Faelle'.

* EGRE: Eltern - Grosseltern .
if ( (Mutter=1 & gmnr=EF53) |   /* Muetter mit Grossmuettern im HH */
     (Vater =1 & gvnr=EF55) )   /* Vaeter  mit Grossvaetern im HH */
   EGRE = 1.
var lab EGRE 'Eltern mit Grosseltern im Haushalt'.
formats Konvproc EGRE (f1.0).
execute.

* Vorbereitung MATCH Konversionstabelle.
do if (EGRE=1 & KonvProc=1).    /* ELTERN MIT GROSSELTERN, im Inland geborene */
    recode MIG2   (else=copy) into mig_k. /* MIG-Status Eltern vor Konversion */
    recode MIG_GV (sysmis=99) (else=copy) into migV_k. /* MIG-Status Grossv.  */
    recode MIG_GM (sysmis=99) (else=copy) into migM_k. /* MIG-Status Grossm.  */
end if.
formats mig_k migV_k migM_k (f2.0).
execute.

* Sortierung fuer Match mit Konversionsprozedur.
sort cases by mig_k migV_k migM_k KonvProc.

* ------------------------------------------------------ .
* Datei conversion.sav (ex: ex: conversion_2011.xls) enthaelt die Variablen: .
*  MIG_K  Migrationsstatus der Person (hier: Vater) (SAS: _mig_).
*  MIGV_K Migrationsstatus des Vaters (hier: Grossvater) (SAS: _migv_).
*  MIGM_K Migrationsstatus der Mutter (hier: Grossmutter) (SAS: _migm_).
*  Konvproc (Konstante: 1) Hilfsvariable fuer Match.
*  MIGNEU Migrationsstatus nach Konversion (Rekodierung).
*  KENNUNG Nr. der Konversion (Rekodierung).
*  --- Beispiele Rekodierung (conversion.sav) ---.
*  MIG_K  MIGV_K  MIGM_K MIGNEU .
*    42     32      42     43   . 
*    77     21      11     52   .
*    77     21      21     62   .
* ------------------------------.
* MIG-Codes: .
*  11 'Vertriebene vor 1950' .
*  21 'Deutsche Zuwanderer oder (Spaet-)Aussiedler (ohne 
*      Einbuergerung)' .
*  42 'Als Auslaender im heutigen Bundesgebiet geboren, entweder beide 
*      Eltern als Auslaender zugewandert oder der eine Elternteil' .
*  43 'Als Auslaender im heutigen Bundesgebiet geboren, beide Eltern 
*      im heutigen Bundesgebiet geboren' .
*  32 'Als Auslaender im heutigen Bundesgebiet geboren und 
*      zwischenzeitlich eingebuergert' .
*  52 'Deutscher mit einseitigem Migrationshintergrund; Migrationsstatus
*      durchweg identifizierbar, weil mit Eltern im Haushalt'.
*  62 'Deutscher mit beidseitigem Migrationshintergrund; Migrationsstatus
*      durchweg identifizierbar, weil mit Eltern im Haushalt'.
*  77 'uneindeutig ob deutsch, vertrieben oder Spaetaussiedler' .
* ---------------------------------------------------------------.
match files file = *
            table = 'conversion.sav' 
     /by mig_k migV_k migM_k KonvProc.

* Neu bilden, da durch Match ueberschrieben.
if not any (MIG2, 11, 21, 22, 23, 25, 29, 31, 41) KonvProc=1.

* Ausgangssortierung.
sort cases by  EF1 EF3 V4 V5.

* Uebernahme konvertierter MIG-Typisierung.
if not(sysmis(migneu)) MIG3 = migneu.
if (sysmis(migneu))    MIG3 = MIG2.
formats MIG3 (f2.0).
var label MIG3   'Migrationsstatus nach Endtypisierung Eltern'.
val label MIG3
    0 'SYSMIS'
   11 'Vertriebene vor 1950'
   21 'Deutsche Zuwanderer oder (Spaet-)Aussiedler (ohne Einbuergerung)'
   22 'Ehegatte oder Kind eines (Spaet-)Aussiedlers (mit/ohne Einbuergerung)'
   25 '(Spaet-)Aussiedler (mit Einbuergerung)'
   29 '(Spaet-)Aussiedler (mit/ohne Einbuergerung) o.A. zum Zuzugsjahr'
   31 'zugewanderte/r eingebuergerte/r Auslaender/in'
   32 'nicht zugewanderte/r eingebuergerte/r Auslaender/in'
   41 'zugewanderte/r Auslaender/in'
   42 'nicht zugewanderte/r Auslaender/in'
   77 'uneindeutig ob deutsch, vertrieben oder Spaetaussiedler'
   99 'fehlende/unvollstaendige Angaben'.
execute.

* SA_erw durch aussagekraeftigen Vatereintrag und Muttereintrag .
*        ergaenzen, sofern noetig und moeglich .
*    SA_erw zur Kontrolle der Rekodierung als SA_erw0 sichern.
compute SA_erw0 = SA_erw.
do if (KonvProc=1 & EGRE=1).
   if ( (SA_erw=0 | SA_erw=99) & (SAerw_GV<>0 | SAerw_GV<>99) ) SA_erw=SAerw_GV.
   if ( (SA_erw=0 | SA_erw=99) & (SAerw_GM<>0 | SAerw_GM<>99) ) SA_erw=SAerw_GM.
end if.
execute.

* Ausgangssortierung .
sort cases by  EF1 EF3 V4 V5 .

* Loeschen Arbeitsvariable.
delete variables sa_erw0.



* ====================================================================.
* 5. Endtypisierung Befragte                                          .
*       Analog zur Endtypisierung der Eltern wird der endgueltige     .
*       Migrationsstatus unter Beruecksichtigung der Kombinationen    .
*       von eigenem, vaeterlichen und muetterlichen vorlaeufigen      .
*       Migrationsstatus zugewiesen, wobei auch hier die Zuweisungen  .
*       nur fuer die im Inland Geborenen zur Anwendung kommen, und    .
*       die erweiterte Staatsangehoerigkeit (SA_erw) ggf. durch       .
*       Angaben des Vaters bzw. der Mutter ergaenzt wird.             .
*       Die Variable SA_erw ist Basis der Staatsangehoerigkeit zum    .
*       Migrationsstatus (MIGS).                                      .

* Ausgangssortierung.
sort cases by EF1 EF3 V4 V5.

* Migrationsrelevante Eintraege fuer Vaeter speichern .
*    MIG  SA1 SA2 SA3 SA SA_erw JZuzug.
temporary.
select if (Vater=1).
save outfile = 'temp_V.sav'
         /keep EF3 V4 V5 MIG3  SA1   SA2    SA3    SA    SA_erw   JZuzug 
         /rename (V5  MIG3  SA1   SA2    SA3    SA    SA_erw   JZuzug = 
                  vnr MIG_V SA1_V SA2_V  SA3_V  SA_V  SA_erw_V JZuzug_V).
execute.

* Sortierung fuer Zusammenspielen Befragten- mit Vaeterangaben.
sort cases by EF1 EF3 V4 vnr.

* Angaben der Vaeter zuspielen. 
match files file=*
           /table='temp_V.sav'
           /by EF3 V4 vnr.
execute.

* Ausgangssortierung.
sort cases by  EF1 EF3 V4 V5.

* ---------------------------------------------------------------- .
* Migrationsrelevante Eintraege fuer Muetter speichern .
*    MIG SA1 SA2 SA3 SA SA_erw JZuzug.
temporary.
select if (Mutter=1).
save outfile = 'temp_M.sav'
         /keep EF3 V4 V5 MIG3  SA1   SA2    SA3    SA    SA_erw    JZuzug 
         /rename (V5   MIG3  SA1   SA2    SA3    SA    SA_erw    JZuzug = 
                  mnr  MIG_M SA1_M SA2_M  SA3_M  SA_M  SA_erw_M  JZuzug_M).
execute.

* Sortieren fuer Zusammenspielen Befragten- mit Muetterangaben.
sort cases by EF1 EF3 V4 mnr.

* Angaben der Muetter zuspielen. 
match files file=*
           /table='temp_M.sav'
           /by EF3 V4 mnr.
execute.
* Ausgangssortierung.
sort cases by  EF1 EF3 V4 V5.

* Vorher zugespielte Variablen aus conversion.sav loeschen.
delete variables mig_k migV_k migM_k Konvproc migneu kennung.   

* Konversions-Prozedur nur fuer im Inland Geborene .
if not any (MIG3, 11, 21, 22, 23, 25, 29, 31, 41) KonvProc=1.
execute.

* Vorbereitung MATCH Konversionstabelle (conversion.sav) .
do if (KonvProc=1).
    recode MIG3   (else=copy) into mig_k. /* MIG-Status Person vor Konvers. */
    recode MIG_V  (sysmis=99) (22 23=21) (else=copy) into migV_k. /* Vater  */
    recode MIG_M  (sysmis=99) (22 23=21) (else=copy) into migM_k. /* Mutter */
end if.
formats mig_k migV_k migM_k (f2.0).
execute.

* Sortierung fuer Match mit Konversionsprozedur.
sort cases by mig_k migV_k migM_k KonvProc.

match files file = *
            table = 'conversion.sav' 
     /by mig_k migV_k migM_k KonvProc.

* Ausgangssortierung.
sort cases by  EF1 EF3 V4 V5.

* neu bilden, da durch Match ggf. ueberschrieben.
if not any (MIG3, 11, 21, 22, 23, 25, 29, 31, 41) KonvProc=1.
execute.

* Migrationsstatus NACH Konversion zuweisen.
if not(sysmis(migneu)) MIG4 = migneu.
if (sysmis(migneu))    MIG4 = MIG3.

var label MIG4 'Migrationsstatus nach Endtypisierung Befragte'.
formats MIG4 (f2.0).
execute.
* fre MIG4.

* SA_erw durch aussagekraeftigen Vatereintrag und Muttereintrag .
*        ergaenzen, sofern noetig und moeglich .
*    SA_erw zur Kontrolle der Rekodierung als SA_erw0 sichern.
compute SA_erw0 = SA_erw.
do if (KonvProc=1).
   if ( (SA_erw=0 | SA_erw=99) & (SA_erw_V<>0 | SA_erw_V<>99) ) SA_erw=SA_erw_V.
   if ( (SA_erw=0 | SA_erw=99) & (SA_erw_M<>0 | SA_erw_M<>99) ) SA_erw=SA_erw_M.
end if.
execute.

* SUF Value Labels & Vergroeberung.
val label MIG4
   0 'Deutsch ohne Migrationshintergrund'
  11 'Bis einschliesslich 1949 als Deutscher ohne Einbuergerung ' 
   + 'auf das heutige Bundesgebiet zugewandert'
  21 '21/29: 1950 und spaeter als Deutscher ohne Einbuergerung '
   + 'auf das heutige Bundesgebiet zugewandert(Spaetaussiedler) (21) '
   + '(Spaet-)Aussiedler (mit/ohne Einbuergerung) o.A. zum Zuzugsjahr (29)'
  22 'Ehegatte oder Kind von Spaetaussiedler, zeitgleich eingereist'
  25 'Spaetaussiedler mit formaler Einbuergerung'
  29 '(Spaet-)Aussiedler (mit/ohne Einbuergerung) o.A. zum Zuzugsjahr'
  31 'Als Auslaender auf das heutige Bundesgebiet zugewandert '
   + 'und zwischenzeitlich eingebuergert'
  32 'Als Auslaender im heutigen Bundesgebiet geboren und '
   + 'zwischenzeitlich eingebuergert'
  41 'Als Auslaender auf das heutige Bundesgebiet zuwandert'
  42 'Als Auslaender im heutigen Bundesgebiet geboren, entweder '
   + 'beide Eltern als Auslaender zugewandert oder der eine Elternteil'
  43 'Als Auslaender im heutigen Bundesgebiet geboren, beide Eltern '
   + '	'
  52 'Deutscher mit einseitigem Migrationshintergrund; Migrationsstatus '
   + 'durchweg identifizierbar, weil mit Eltern im Haushalt'
  53 'Deutscher mit einseitigem Migrationshintergrund; Migrationsstatus '
   + 'durchweg identifizierbar, weil mit Eltern im Haushalt'
  54 'Deutscher mit einseitigem Migrationshintergrund; Migrationsstatus '
   + 'durchweg identifizierbar, weil mit Eltern im Haushalt'
  62 'Deutscher mit beidseitigem Migrationshintergrund; Migrationsstatus '
   + 'durchweg identifizierbar, weil mit Eltern im Haushalt'
  63 'Deutscher mit beidseitigem Migrationshintergrund; Migrationsstatus '
   + 'durchweg identifizierbar, weil mit Eltern im Haushalt'
  64 'Deutscher mit beidseitigem Migrationshintergrund; Migrationsstatus '
   + 'durchweg identifizierbar, weil mit Eltern im Haushalt'
  77 'uneindeutig ob deutsch, vertrieben oder Spaetaussiedler'.
formats mig4 (f2.0).
execute.


* 6. Umsetzung von Zeitreihenkompatibilitaet entfaellt im MZ 2008 .


* ====================================================================.
* 7. Variablendefinitionen wie im SUF und fuer Fachserien-Ergebnisse  .

*    MIG Recodierung / Vergroeberung wie im SUF 29=>21.
recode MIG4 (29=21) (77=0) (else=copy) into MIG.
var label MIG 'Migrationsstatus'.
formats MIG (f2.0).
val lab MIG 
    0 'Deutsch ohne Migrationshintergrund '
    + 'uneindeutig ob deutsch, vertrieben oder Spaetaussiedler (MIG4=77)'
   11 'Bis einschliesslich 1949 als Deutscher ohne Einbuergerung auf '
    + 'das heutige Bundesgebiet zugewandert'
   21 '21/29: 1950 und spaeter als Deutscher ohne Einbuergerung auf '
    + 'das heutige Bundesgebiet zugewandert(Spaetaussiedler)(21); '
    + 'Ohne Angabe des Zuzugsjahrs als Deutscher ohne Einbuergerung '
    + 'auf das heutige Bundesgebiet zuwandert(29)'
   22 'Ehegatte oder Kind von Spaetaussiedler, zeitgleich eingereist'
   25 'Spaetaussiedler mit formaler Einbuergerung'
   31 'Als Auslaender auf das heutige Bundesgebiet zugewandert und '
    + 'zwischenzeitlich eingebuergert'
   32 'Als Auslaender im heutigen Bundesgebiet geboren und '
    + 'zwischenzeitlich eingebuergert'
   41 'Als Auslaender auf das heutige Bundesgebiet zuwandert'
   42 'Als Auslaender im heutigen Bundesgebiet geboren, entweder '
    + 'beide Eltern als Auslaender zugewandert oder der eine '
    + 'Elternteil als Auslaender zugewandert, der andere als '
    + 'Auslaender im heutigen Bundesgebiet geboren'
   43 'Als Auslaender im heutigen Bundesgebiet geboren, beide Eltern '
    + 'im heutigen Bundesgebiet geboren'
   52 'Deutscher mit einseitigem Migrationshintergrund; '
    + 'Migrationsstatus durchweg identifizierbar, weil mit Eltern im '
    + 'Haushalt lebend; ein Elternteil ist Spaetaussiedler (21-29)'
   53 'Deutscher mit einseitigem Migrationshintergrund; '
    + 'Migrationsstatus durchweg identifizierbar, weil mit Eltern '
    + 'im Haushalt lebend; ein Elternteil ist Deutscher durch '
    + 'Einbuergerung (31, 32)'
   54 'Deutscher mit einseitigem Migrationshintergrund; '
    + 'Migrationsstatus durchweg identifizierbar, weil mit Eltern im '
    + 'Haushalt lebend; ein Elternteil ist Auslaender (41-43)'
   62 'Deutscher mit beidseitigem Migrationshintergrund; '
    + 'Migrationsstatus durchweg identifizierbar, weil mit Eltern im '
    + 'Haushalt lebend; mind. 1 Elternteil ist Spaetaussiedler (21-29)'
   63 'Deutscher mit beidseitigem Migrationshintergrund; '
    + 'Migrationsstatus durchweg identifizierbar, weil mit Eltern im '
    + 'Haushalt lebend; entweder beide Eltern eingebuergert oder 1 '
    + 'Elternteil eingebuergert (31, 32), der andere Auslaender (41-43)'
   64 'Deutscher mit beidseitigem Migrationshintergrund; '
    + 'Migrationsstatus durchweg identifizierbar, weil mit Eltern im '
    + 'Haushalt lebend; beide Eltern sind Auslaender (41-43), es '
    + 'handelt sich um ein ius soli-Kind (Optionsmodell)'.
execute.

* MIGS: Vergroeberungen, Rekodierungen SA_erw => migs wie SUF.
compute MIGS = sa_erw.
if (MIG=0) MIGS=0.
var lab MIGS 'Staatsangehoerigkeit: Migrationsstatus'.
val lab MIGS 
    0 'Deutsch ohne Migrationshintergrund'
    2 'Bosnien und Herzegowina'
    4 '4/8/27: Daenemark(4); Finnland(8); Schweden(27)'
    5 'Ehemalige Sowjetunion'
    6 'Ehemaliges Jugoslawien'
    9 'Frankreich'
   10 'Griechenland'
   13 'Italien'
   14 'Kroatien'
   21 '1/18/21: Belgien(1); Luxemburg(18); Niederlande(21)'
   22 'oesterreich'
   23 'Polen'
   24 'Portugal'
   25 '3/25: Bulgarien(3); Rumaenien(25)'
   26 'Russische Foederation'
   28 '12/16/20/28: Island(12); Liechtenstein(16); Norwegen(20); Schweiz(28)'
   31 '7/15/17/19/31/37: Estland(7); Lettland(15); Litauen(17); '
    + 'Malta(19); Slowenien(31); Zypern(37)'
   32 'Spanien'
   33 '30/33: Slowakei(30); Tschechische Republik(33)'
   34 'Tuerkei'
   35 'Ungarn'
   36 '11/36: Irland(11); Vereinigtes Koenigreich(36)'
   38 'Sonstiges Osteuropa'
   39 'Sonstiges Europa'
   40 'Marokko'
   41 'Sonstiges Nordafrika'
   42 'Sonstiges Afrika (ohne Marokko)'
   43 'Vereinigte Staaten von Amerika (USA)'
   45 '44/45: Sonstiges Nordamerika [Kanada](44); Mittelamerika und '
    + 'Karibik(45)'
   46 'Suedamerika'
   47 'Irak'
   48 'Iran'
   49 'Sonstiger Naher und Mittlerer Osten (ohne Iran)'
   50 'Vietnam'
   51 'Afghanistan'
   52 'Sonstiges Sued- und Suedostasien'
   53 'China'
   54 'Sonstiges Ostasien'
   55 '55/98: Uebrige Welt(55); Staatenlos(98)'
   56 'Ukraine'
   57 'Kasachstan'
   58 'Serbien'
   59 'Montenegro'.
formats mig migs (f2.0).
execute.


* ======= ENDE MIG-TYPISIERUNG ===== .


* Variablendefinitionen fuer Fachserien-Ergebnisse. 
* MIGRATIONSTYP => Definitionen fuer Bevoelkerung am Hauptwohnsitz.
* Z# : Lfd. Nr. in Tab. 2 .
recode MIG (0 thru 77=1) (else=sysmis) into Z001.
recode MIG (0 11 77=1) (else=sysmis) into Z002. 
recode MIG (21 thru 29 31 32 41 42 43 52 53 54 62 63 64=1) 
           (else=sysmis) into Z005. 
recode MIG (21 thru 29,31,41=1) (else=sysmis) into Z034.
recode MIG (41=1) (else=sysmis) into Z062.
recode MIG (21 22 25 29 31=1) (else=sysmis) into Z089.
recode MIG (21 22 25 29=1) (else=sysmis) into Z090.
recode MIG (31=1) (else=sysmis) into Z097.
recode MIG (42 43 32 52 53 54 62 63 64=1) (else=sysmis) into Z119.
recode MIG (42 43=1) (else=sysmis) into Z126.
recode MIG (32 52 53 54 62 63 64=1) (else=sysmis) into Z133.
recode MIG (32=1) (else=sysmis) into Z134.
recode MIG (52 53 54 62 63 64=1) (else=sysmis) into Z140.
recode MIG (62 63 64=1) (else=sysmis) into Z141. 
recode MIG (52 53 54=1) (else=sysmis) into Z142. 
formats Z001 to Z142 (f1.0).
var label Z001 'Bevoelkerung insgesamt'.
var label Z002 'Personen ohne Mig-hintergrund'.
var label Z005 'Personen mit Mig-hintergrund i.e.S.'.
var label Z034 'Personen mit eigener Mig-erfahrung'.
var label Z062 '+ Auslaender'.
var label Z089 '+ Deutsche'.
var label Z090 '  - Spaetaussiedler'.
var label Z097 '  - durch Einbuergerung'.
var label Z119 'Personen ohne eigene Mig-erfahrung'.
var label Z126 '+ Auslaender'. 
var label Z133 '+ Deutsche'.
var label Z134 '  - durch Einbuergerung'.
var label Z140 '  - mit mind. 1 zugew. o. als Ausl. in D geb. Elternteil'.
var label Z141 '    # mit beidseitigem Mig-hintergrund'.
var label Z142 '    # mit einseitigem Mig-hintergrund'.
execute.

* STAATSANGEHOERIGKEITEN zum Migrationsstatus zeitreihenkompatibel (MIG) 
* Deutsche Zuwanderer ohne Einbuergerung sowie in Deutschland geborene 
* Deutsche mit ein-/beidseitigem Migrationshintergund => 0 (deutsch) .
compute MIGS_R = MIGS.
do if any(MIG, 0,11,21,22,23,25,29,61,62,63,64,71,72,73,74).
+ compute MIGS_R = 0.
end if.
formats MIGS_R (f2.0).
var lab MIGS_R 'Erw. Staatsangeh. zum Mig-status 2005 zeitreihenkompatibel recodiert'.
execute.

* Staatsangehoerigkeiten (MIGS_R) - Tab. 2 FS 1, R 2.2 .
* - Personen mit Migrationshintergrund im engeren Sinn  - .
* Z## :  Lfd. Nr. in Tab. 2 .
recode MIGS_R (0 thru 99=1) (else=sysmis) into Z00.
recode MIGS_R (01 thru 39 56 thru 59=1) (else=sysmis) into Z06.
recode MIGS_R (4 9 10 13 21 thru 25 31 32 33 35 36=1) (else=sysmis) into Z07.
recode MIGS_R (10=1) (else=sysmis) into Z08.
recode MIGS_R (13=1) (else=sysmis) into Z09.
recode MIGS_R (23=1) (else=sysmis) into Z10.
recode MIGS_R (2 5 6 14 26 28 34 38 39 56 57 58 59=1) (else=sysmis) into Z12.
recode MIGS_R (2=1) (else=sysmis) into Z13.
recode MIGS_R (14=1) (else=sysmis) into Z14.
recode MIGS_R (26=1) (else=sysmis) into Z15.
recode MIGS_R (58 59=1) (else=sysmis) into Z16.
recode MIGS_R (34=1) (else=sysmis) into Z17.
recode MIGS_R (56=1) (else=sysmis) into Z18.
recode MIGS_R (40 41 42=1) (else=sysmis) into Z19.
recode MIGS_R (43 thru 46=1) (else=sysmis) into Z20.
recode MIGS_R (47 thru 54 57=1) (else=sysmis) into Z22.
recode MIGS_R (47 48 49 57=1) (else=sysmis) into Z23.
recode MIGS_R (57=1) (else=sysmis) into Z24.
recode MIGS_R (50 51 52=1) (else=sysmis) into Z25.
recode MIGS_R (0 55 98=1) (else=sysmis) into Z26.
formats Z00 to Z26 (f1.0).
var lab Z00 'Insgesamt [0-99]'.
var lab Z06 'Europa [01-39,56-59]'.
var lab Z07 'o EU 27 [4,9,10,13,21-25,31-33,35,36]'.
var lab Z08 '  - Griechenland [10]'.
var lab Z09 '  - Italien [13]'.
var lab Z10 '  - Polen [23]'.
var lab Z12 'o Sonstiges Europa [2,5,6,14,26,28,34,38,39,56-59]'.
var lab Z13 '  - Bosnien und Herzegowina [2]'.
var lab Z14 '  - Kroatien [14]'.
var lab Z15 '  - Russische Foederation [26]'.
var lab Z16 '  - Serbien und Montenegro [58-59]'.
var lab Z17 '  - Tuerkei [34]'.
var lab Z18 '  - Ukraine [56]'.
var lab Z19 'Afrika [40-42]'.
var lab Z20 'Amerika [43-46]'.
var lab Z22 'Asien, Australien und Ozeanien [47-54,57]'.
var lab Z23 'o Naher und Mittlerer Osten [37-49,57]'.
var lab Z24 '  - Kasachstan [57]'.
var lab Z25 'o Sued- und Suedostasien [50-52]'.
var lab Z26 'Ohne Angabe bzw. unzutreffend [0,55,98]'.
execute.


* Sortierung nach Ordnungsnummern fuer Zuspielen der erstellten .
* Variablen MIG zum Scientific Use File .
sort cases by EF1 EF3 EF4 EF5b EF12 EF5a.

* Zwischenspeicherung.
save outfile = 'mig2008.sav'.

* =====================================================================.

* Kontrolle: MIG ?=? MIG-Originalvariable .
temporary.
select if mig<>mig_o.
crosstabs mig by mig_o.
* Differenzen: .
* MIG=32 vs. MIG_O=31: n =  78 --- OK, da Unterschied Jahresbestand/-?erhang (in MIG_O im SUF) aufgehoben;
* MIG=42 vs. MIG_O=43: n = 234 --- OK, da neue Konversionstabelle .

* Kontrolle: MIGS ?=? MIGS-Originalvariable . 
temporary. 
select if migs<>migs_o. 
value label migs ''. 
value label migs_o ''. 
crosstabs mig migs by migs_o.
* OK, keine Differenzen.

* Fallzahlen. 
temporary. 
weight off.
fre mig migs.

* Hochgerechnete Verteilungen von MIG und MIGS. 
temporary. 
* Bevoelkerung am Hauptwohnsitz. 
select if (EF30>=1 & EF30<=2). 
* Hochrechnung Jahresdurchschnitt. 
weight by EF952. 
fre mig migs.

* Vergleich mit Tabelle 2, S. 64 in: Statistisches Bundesamt, 2010: . 
* Fachserie 1 Bevoelkerung und Erwerbstaetigkeit, Reihe 2.2 . 
* Bevoelkerung mit Migrationshintergrund. Ergebnisse des Mikrozensus . 
* 2008. Wiesbaden . 
temporary. 
* Bevoelkerung am Hauptwohnsitz. 
select if (EF30>=1 & EF30<=2). 
* Hochrechnung Jahresdurchschnitt. 
weight by EF952. 
descriptives variables = Z001 to Z142  /statistics sum.

temporary. 
* Bevoelkerung am Hauptwohnsitz. 
select if (EF30>=1 & EF30<=2). 
* Hochrechnung Jahresdurchschnitt. 
weight by EF952. 
* Personen mit Migrationshintergrund im engeren Sinn (mig=21-64) . 
select if (mig>=21 & mig<=64). 
* ZU BEACHTEN: Aufgrund fehlender differenzierter Angaben zur . 
* 2. Staatsangehoerigkeit (EF370) koennen Abweichungen zur Fachserie auftreten. 
descriptives variables = Z005 Z00 to Z26  /statistics sum.


* ################################################################################.
* PROGRAMMENDE .

